@@ -19,15 +19,19 @@ module MCollective
       end
 
       def []=(key, val)
-        raise "Can only store String, Integer, Float or Boolean data but got #{val.class} for key #{key}" unless [String, Fixnum, Float, TrueClass, FalseClass].include?(val.class)
+        raise "Can only store String, Integer, Float or Boolean data but got #{val.class} for key #{key}" unless [String, Fixnum, Bignum, Float, TrueClass, FalseClass].include?(val.class)
 
         @data[key.to_sym] = val
       end
 
+      def keys
+        @data.keys
+      end
+
       def method_missing(method, *args)
         key = method.to_sym
 
-        raise NameError, "undefined local variable or method `%s'" % key unless include?(key)
+        raise NoMethodError, "undefined local variable or method `%s'" % key unless include?(key)
 
         @data[key]
       end
